/**
 * @file	intl.h
 * @brief	sample of intl.h for tiny_gettext
 */
#ifndef INTL_H
#define INTL_H


#if HAVE_LOCALE_H
 #include <locale.h>
#endif
#if !HAVE_SETLOCALE
 #define setlocale(C,L)
#endif


#if HAVE_TINY_GETTEXT != 0 || ENABLE_NLS == 0
 #if HAVE_TINY_GETTEXT
  #ifdef __cplusplus
  extern "C" {
  #endif
  const char *	gettext(const char *  msgId);
  const char *	ngettext(const char *  msg1, const char * msg2, int n);
  const char * 	textdomain(const char *domainName);
  #ifdef __cplusplus
  }
  #endif
 #else
  #define gettext(x)					(x)
  #define ngettext(s1,s2,n)				(((n) == 1) ? (s1) : (s2))
  #define textdomain(x)					(x)
 #endif
 #define gettext_noop(x)				(x)
 #define bindtextdomain(d,dir)			("")
 #define bind_textdomain_codeset(d,c)	(d)
 #define dgettext(d,s)					gettext(s)
 #define dcgettext(d,s,c)				gettext(s)
 #define dngettext(d,s1,s2,f)			ngettext(s1,s2,f)
 #define dcngettext(d,s1,s2,f,c)		ngettext(s1,s2,f)
#else
 #include <libintl.h>
#endif

#define _(x) 							gettext(x)

#ifdef gettext_noop
 #define N_(x) 							gettext_noop(x)
#else
 #define N_(x) 							(x)
#endif


#endif	/* INTL_H */
